@@ -317,7 +317,9 @@ class waveAnalysis(object):
                     # Get desired time interval
                     time_var = ncs.variables["TIME"]
                     tt = ncs.variables["TIME"][:]
-                    timing = netCDF4.num2date(tt, time_var.units)
+                    timing = netCDF4.num2date(tt, time_var.units
+                                             only_use_cftime_datetimes=False,
+                                             only_use_python_datetimes=True)
                     self.time_units = time_var.units
                     timebound = np.where(
                         np.logical_and(
@@ -955,7 +957,9 @@ class waveAnalysis(object):
         self.speed = self.waveGroupVelocity(self.T)
         self.power1 = self.waveEnergyFlux(self.wh, self.T)
 
-        sort_time = netCDF4.num2date(self.times.astype(float), self.time_units)
+        sort_time = netCDF4.num2date(self.times.astype(float), self.time_units,
+                                     only_use_cftime_datetimes=False,
+                                     only_use_python_datetimes=True)
 
         wavedf = pd.DataFrame(
             data={
